@@ -81,7 +81,7 @@ sub ProcessMPC($$)
     my ($exifTool, $dirInfo) = @_;
 
     # must first check for leading ID3 information
-    unless ($exifTool->{DONE_ID3}) {
+    unless ($exifTool->{DoneID3}) {
         require Image::ExifTool::ID3;
         Image::ExifTool::ID3::ProcessID3($exifTool, $dirInfo) and return 1;
     }
@@ -106,7 +106,7 @@ sub ProcessMPC($$)
         $exifTool->ProcessDirectory(\%dirInfo, $tagTablePtr);
     } else {
         $exifTool->Warn('Audio info not currently extracted from this version MPC file');
-    } 
+    }
 
     # process APE trailer if it exists
     require Image::ExifTool::APE;
